/*
 boardCap.c
 ***********************************************************************
 This program captures a picture from our BoardFax by generating the
 poixel clock and sync pulse from the RaspberryPi while reading the 
 pixel data through another GPIO pin of the raspberryPi.

 pin0  output   pixel clock
 pin1  output   sync pulse (begin of the pixel line)
 pin2  input    pixel data

 CC BY-NC-SA 2014 c-hack.de
 *********************************************************************** 
*/

#include <stdio.h>
#include <wiringPi.h>

#define CLK     1
#define	SYNC	16
#define PIX     12

#define PIXEL_SIZE  2048
#define RAW_X 3000
#define RAW_Y 2500


char picture [RAW_X][RAW_Y];


int main(void)
{
  int i;

  printf("Raspberry Pi BoardFaxHack\n");
  printf("cc-by-sa-nc  2014   c-hack.de\n\n");
  printf("Capturing Data...\n");

  wiringPiSetup();
  for (i=0; i<16; i++) pinMode(i,INPUT);
  pinMode(CLK, OUTPUT);
  pinMode(SYNC, OUTPUT);
  pinMode(PIX, INPUT);
  
  /* ------ Initialize ------------------*/
  digitalWrite(SYNC, LOW);   // SYNC low
  digitalWrite(CLK, LOW);    // Clock off
  /* ------------------------------------*/

  lineCapture(0);

  for (i=0; i<RAW_Y; i++) 
     if(picture[0][i] == 0) printf("."); else printf("#"); 

  printf("Capture finished");
}


// Captures one line including overhead
void lineCapture(int x_index) {
   int i;
   int bit;

   digitalWrite(SYNC,LOW);   // One SYNC pulse
   digitalWrite(SYNC,HIGH);
   delayMicroseconds(2);
   digitalWrite(SYNC,LOW);

   for (i=0; i<RAW_Y; i++) {
      digitalWrite(CLK, HIGH);
      delayMicroseconds(1);
      picture[x_index][i] = (char) digitalRead(PIX);
      digitalWrite(CLK, LOW);
      delayMicroseconds(2);
   }
}
